@@ -26,6 +26,29 @@ class GsClient(AbstractClient):
     _service = 'gs'
 
 
+    def BackUpAndroidInstance(self, request):
+        r"""备份安卓实例。该接口需要联系我们开通内网存储才能使用。
+
+        :param request: Request instance for BackUpAndroidInstance.
+        :type request: :class:`tencentcloud.gs.v20191118.models.BackUpAndroidInstanceRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.BackUpAndroidInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BackUpAndroidInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.BackUpAndroidInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def BackUpAndroidInstanceToStorage(self, request):
         r"""备份云手机数据到指定存储，支持 COS 和兼容 AWS S3 协议的对象存储服务。如果是备份到 COS 时，会使用公网流量，授权 COS bucket 请在控制台中操作。
 
@@ -467,6 +490,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAndroidInstanceBackups(self, request):
+        r"""批量删除安卓实例备份
+
+        :param request: Request instance for DeleteAndroidInstanceBackups.
+        :type request: :class:`tencentcloud.gs.v20191118.models.DeleteAndroidInstanceBackupsRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.DeleteAndroidInstanceBackupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAndroidInstanceBackups", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAndroidInstanceBackupsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAndroidInstanceImages(self, request):
         r"""删除安卓实例镜像
 
@@ -559,6 +605,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAndroidInstanceBackups(self, request):
+        r"""查询安卓实例备份列表
+
+        :param request: Request instance for DescribeAndroidInstanceBackups.
+        :type request: :class:`tencentcloud.gs.v20191118.models.DescribeAndroidInstanceBackupsRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.DescribeAndroidInstanceBackupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAndroidInstanceBackups", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAndroidInstanceBackupsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAndroidInstanceImages(self, request):
         r"""查询安卓实例镜像信息，当镜像的 AndroidInstanceImageState 为 NORMAL 时，镜像处于可用状态。
 
@@ -789,6 +858,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DistributeAndroidInstanceImageToHosts(self, request):
+        r"""分发安卓实例镜像至宿主机
+
+        :param request: Request instance for DistributeAndroidInstanceImageToHosts.
+        :type request: :class:`tencentcloud.gs.v20191118.models.DistributeAndroidInstanceImageToHostsRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.DistributeAndroidInstanceImageToHostsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DistributeAndroidInstanceImageToHosts", params, headers=headers)
+            response = json.loads(body)
+            model = models.DistributeAndroidInstanceImageToHostsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DistributeFileToAndroidInstances(self, request):
         r"""将一个文件批量分发到多个实例，一次接口调用触发一次文件分发，一次文件分发只会从公网下载一次，然后文件会走内网分发到实例列表中的实例。
 
@@ -1344,6 +1436,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RestoreAndroidInstance(self, request):
+        r"""还原安卓实例。该接口需要联系我们开通内网存储才能使用。
+
+        :param request: Request instance for RestoreAndroidInstance.
+        :type request: :class:`tencentcloud.gs.v20191118.models.RestoreAndroidInstanceRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.RestoreAndroidInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestoreAndroidInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.RestoreAndroidInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RestoreAndroidInstanceFromStorage(self, request):
         r"""使用指定存储数据还原云手机，支持 COS 和兼容 AWS S3 协议的对象存储服务。如果还原数据来自 COS 时，会使用公网流量，授权 COS bucket 请在控制台中操作。
 
