@@ -19,7 +19,7 @@ from tencentcloud.common.abstract_model import AbstractModel
 
 
 class EvaluationRequest(AbstractModel):
-    """Evaluation请求参数结构体
+    r"""Evaluation请求参数结构体
 
     """
 
@@ -68,7 +68,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def SessionId(self):
-        """图片唯一标识，一张图片一个SessionId；
+        r"""图片唯一标识，一张图片一个SessionId；
         :rtype: str
         """
         return self._SessionId
@@ -79,7 +79,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def Image(self):
-        """图片数据，需要使用base64对图片的二进制数据进行编码，与url参数二者填一即可；
+        r"""图片数据，需要使用base64对图片的二进制数据进行编码，与url参数二者填一即可；
         :rtype: str
         """
         return self._Image
@@ -90,7 +90,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def HcmAppid(self):
-        """业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 HcmAppid 可以在[控制台](https://console.cloud.tencent.com/hcm)【应用管理】下新建。
+        r"""业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 HcmAppid 可以在[控制台](https://console.cloud.tencent.com/hcm)【应用管理】下新建。
         :rtype: str
         """
         return self._HcmAppid
@@ -101,7 +101,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def Url(self):
-        """图片url，与Image参数二者填一即可；
+        r"""图片url，与Image参数二者填一即可；
         :rtype: str
         """
         return self._Url
@@ -112,7 +112,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def SupportHorizontalImage(self):
-        """横屏拍摄开关，若开启则支持传输横屏拍摄的图片；
+        r"""横屏拍摄开关，若开启则支持传输横屏拍摄的图片；
         :rtype: bool
         """
         return self._SupportHorizontalImage
@@ -123,7 +123,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def RejectNonArithmeticImage(self):
-        """拒绝非速算图（如风景图、人物图）开关，若开启，则遇到非速算图会快速返回拒绝的结果，但极端情况下可能会影响评估结果（比如算式截图贴到风景画里可能被判为非速算图直接返回了）。
+        r"""拒绝非速算图（如风景图、人物图）开关，若开启，则遇到非速算图会快速返回拒绝的结果，但极端情况下可能会影响评估结果（比如算式截图贴到风景画里可能被判为非速算图直接返回了）。
         :rtype: bool
         """
         return self._RejectNonArithmeticImage
@@ -136,7 +136,7 @@ class EvaluationRequest(AbstractModel):
     def IsAsync(self):
         warnings.warn("parameter `IsAsync` is deprecated", DeprecationWarning) 
 
-        """异步模式标识，0：同步模式，1：异步模式。默认为同步模式
+        r"""异步模式标识，0：同步模式，1：异步模式。默认为同步模式
         :rtype: int
         """
         return self._IsAsync
@@ -149,7 +149,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def EnableDispRelatedVertical(self):
-        """是否展开耦合算式中的竖式计算
+        r"""是否展开耦合算式中的竖式计算
         :rtype: bool
         """
         return self._EnableDispRelatedVertical
@@ -160,7 +160,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def EnableDispMidresult(self):
-        """是否展示竖式算式的中间结果和格式控制字符
+        r"""是否展示竖式算式的中间结果和格式控制字符
         :rtype: bool
         """
         return self._EnableDispMidresult
@@ -171,7 +171,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def EnablePdfRecognize(self):
-        """是否开启pdf识别，默认开启
+        r"""是否开启pdf识别，默认开启
         :rtype: bool
         """
         return self._EnablePdfRecognize
@@ -182,7 +182,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def PdfPageIndex(self):
-        """pdf页码，从0开始，默认为0
+        r"""pdf页码，从0开始，默认为0
         :rtype: int
         """
         return self._PdfPageIndex
@@ -193,7 +193,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def LaTex(self):
-        """是否返回LaTex，默认为0返回普通格式，设置成1返回LaTex格式
+        r"""是否返回LaTex，默认为0返回普通格式，设置成1返回LaTex格式
         :rtype: int
         """
         return self._LaTex
@@ -204,7 +204,7 @@ class EvaluationRequest(AbstractModel):
 
     @property
     def RejectVagueArithmetic(self):
-        """用于选择是否拒绝模糊题 目。打开则丢弃模糊题目， 不进行后续的判题返回结 果。
+        r"""用于选择是否拒绝模糊题 目。打开则丢弃模糊题目， 不进行后续的判题返回结 果。
         :rtype: bool
         """
         return self._RejectVagueArithmetic
@@ -239,7 +239,7 @@ class EvaluationRequest(AbstractModel):
 
 
 class EvaluationResponse(AbstractModel):
-    """Evaluation返回参数结构体
+    r"""Evaluation返回参数结构体
 
     """
 
@@ -262,7 +262,7 @@ class EvaluationResponse(AbstractModel):
 
     @property
     def SessionId(self):
-        """图片唯一标识，一张图片一个SessionId；
+        r"""图片唯一标识，一张图片一个SessionId；
         :rtype: str
         """
         return self._SessionId
@@ -273,7 +273,7 @@ class EvaluationResponse(AbstractModel):
 
     @property
     def Items(self):
-        """识别出的算式信息；
+        r"""识别出的算式信息；
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: list of Item
         """
@@ -287,7 +287,7 @@ class EvaluationResponse(AbstractModel):
     def TaskId(self):
         warnings.warn("parameter `TaskId` is deprecated", DeprecationWarning) 
 
-        """任务 id，用于查询接口
+        r"""任务 id，用于查询接口
         :rtype: str
         """
         return self._TaskId
@@ -300,7 +300,7 @@ class EvaluationResponse(AbstractModel):
 
     @property
     def RequestId(self):
-        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        r"""唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :rtype: str
         """
         return self._RequestId
@@ -323,7 +323,7 @@ class EvaluationResponse(AbstractModel):
 
 
 class Item(AbstractModel):
-    """识别出的算术式信息及评估结果
+    r"""识别出的算术式信息及评估结果
 
     """
 
@@ -362,7 +362,7 @@ class Item(AbstractModel):
 
     @property
     def Item(self):
-        """识别的算式是否正确，算式运算结果:
+        r"""识别的算式是否正确，算式运算结果:
 ‘YES’:正确 
 ‘NO’: 错误 
 ‘NA’: 非法参数
@@ -377,7 +377,7 @@ class Item(AbstractModel):
 
     @property
     def ItemString(self):
-        """识别出的算式，识别出的文本行字符串
+        r"""识别出的算式，识别出的文本行字符串
         :rtype: str
         """
         return self._ItemString
@@ -388,7 +388,7 @@ class Item(AbstractModel):
 
     @property
     def ItemCoord(self):
-        """识别的算式在图片上的位置信息，文本行在旋转纠正之后的图像中的像素坐 标，表示为(左上角 x, 左上角 y，宽 width， 高 height)
+        r"""识别的算式在图片上的位置信息，文本行在旋转纠正之后的图像中的像素坐 标，表示为(左上角 x, 左上角 y，宽 width， 高 height)
         :rtype: :class:`tencentcloud.hcm.v20181106.models.ItemCoord`
         """
         return self._ItemCoord
@@ -399,7 +399,7 @@ class Item(AbstractModel):
 
     @property
     def Answer(self):
-        """错题推荐答案，算式运算结果正确返回为 ""，算式运算结果错误返回推荐答案 (注:暂不支持多个关系运算符(如 1<10<7)、 无关系运算符(如 frac(1,2)+frac(2,3))、单 位换算(如 1 元=100 角)错题的推荐答案 返回)
+        r"""错题推荐答案，算式运算结果正确返回为 ""，算式运算结果错误返回推荐答案 (注:暂不支持多个关系运算符(如 1<10<7)、 无关系运算符(如 frac(1,2)+frac(2,3))、单 位换算(如 1 元=100 角)错题的推荐答案 返回)
 (注:使用@@标记答案填写区域)
         :rtype: str
         """
@@ -411,7 +411,7 @@ class Item(AbstractModel):
 
     @property
     def ExpressionType(self):
-        """算式题型编号，如加减乘除四则题型，具体题型及编号如下：1 加减乘除四则 2 加减乘除已知结果求运算因子3 判断大小 4 约等于估算 5 带余数除法 6 分数四则运算 7 单位换算 8 竖式加减法 9 竖式乘除法 10 脱式计算 11 解方程
+        r"""算式题型编号，如加减乘除四则题型，具体题型及编号如下：1 加减乘除四则 2 加减乘除已知结果求运算因子3 判断大小 4 约等于估算 5 带余数除法 6 分数四则运算 7 单位换算 8 竖式加减法 9 竖式乘除法 10 脱式计算 11 解方程
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: str
         """
@@ -423,7 +423,7 @@ class Item(AbstractModel):
 
     @property
     def ItemConf(self):
-        """文本行置信度
+        r"""文本行置信度
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: float
         """
@@ -435,7 +435,7 @@ class Item(AbstractModel):
 
     @property
     def QuestionId(self):
-        """用于标识题目 id，如果有若干算式属于同一 题，则其对应的 id 相同。
+        r"""用于标识题目 id，如果有若干算式属于同一 题，则其对应的 id 相同。
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: str
         """
@@ -467,7 +467,7 @@ class Item(AbstractModel):
 
 
 class ItemCoord(AbstractModel):
-    """目标算式在图片上的坐标信息
+    r"""目标算式在图片上的坐标信息
 
     """
 
@@ -489,7 +489,7 @@ class ItemCoord(AbstractModel):
 
     @property
     def Height(self):
-        """算式高度
+        r"""算式高度
         :rtype: int
         """
         return self._Height
@@ -500,7 +500,7 @@ class ItemCoord(AbstractModel):
 
     @property
     def Width(self):
-        """算式宽度
+        r"""算式宽度
         :rtype: int
         """
         return self._Width
@@ -511,7 +511,7 @@ class ItemCoord(AbstractModel):
 
     @property
     def X(self):
-        """算式图的左上角横坐标
+        r"""算式图的左上角横坐标
         :rtype: int
         """
         return self._X
@@ -522,7 +522,7 @@ class ItemCoord(AbstractModel):
 
     @property
     def Y(self):
-        """算式图的左上角纵坐标
+        r"""算式图的左上角纵坐标
         :rtype: int
         """
         return self._Y
