@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,15 +20,12 @@ FAILEDOPERATION_ARREARSERROR = 'FailedOperation.ArrearsError'
 # 身份证CardSide类型错误
 FAILEDOPERATION_CARDSIDEERROR = 'FailedOperation.CardSideError'
 
+# 图片分类失败
+FAILEDOPERATION_CLASSIFYSTOREFAILED = 'FailedOperation.ClassifyStoreFailed'
+
 # 今日次数达到限制。
 FAILEDOPERATION_COUNTLIMITERROR = 'FailedOperation.CountLimitError'
 
-# 数据源查询失败。
-FAILEDOPERATION_DATASOURCEQUERYFAILED = 'FailedOperation.DataSourceQueryFailed'
-
-# 数据库异常。
-FAILEDOPERATION_DBERROR = 'FailedOperation.DbError'
-
 # 检测失败。
 FAILEDOPERATION_DETECTFAILED = 'FailedOperation.DetectFailed'
 
@@ -41,7 +38,10 @@ FAILEDOPERATION_EMPTYIMAGEERROR = 'FailedOperation.EmptyImageError'
 # 引擎识别超时。
 FAILEDOPERATION_ENGINERECOGNIZETIMEOUT = 'FailedOperation.EngineRecognizeTimeout'
 
-# 身份证信息不合法（身份证号、姓名字段校验非法等）。
+# 字段值不符合预期
+FAILEDOPERATION_FIELDEXCEPTION = 'FailedOperation.FieldException'
+
+# 第二代身份证信息不合法或缺失（身份证号、姓名字段校验非法等）
 FAILEDOPERATION_IDCARDINFOILLEGAL = 'FailedOperation.IdCardInfoIllegal'
 
 # 图片分辨率过小或身份证在原图中的占比过小
@@ -59,7 +59,10 @@ FAILEDOPERATION_IMAGEDECODEFAILED = 'FailedOperation.ImageDecodeFailed'
 # 照片未检测到名片。
 FAILEDOPERATION_IMAGENOBUSINESSCARD = 'FailedOperation.ImageNoBusinessCard'
 
-# 图片中未检测到身份证。
+# 图片中未检测到手写体
+FAILEDOPERATION_IMAGENOHANDWRITE = 'FailedOperation.ImageNoHandWrite'
+
+# 图片中未检测到第二代身份证或临时身份证。
 FAILEDOPERATION_IMAGENOIDCARD = 'FailedOperation.ImageNoIdCard'
 
 # 非指定卡类别图片
@@ -68,16 +71,28 @@ FAILEDOPERATION_IMAGENOSPECIFIEDCARD = 'FailedOperation.ImageNoSpecifiedCard'
 # 图片中未检测到文本。
 FAILEDOPERATION_IMAGENOTEXT = 'FailedOperation.ImageNoText'
 
-# 图片尺寸过大，请参考输出参数中关于图片大小限制的说明。
+# 图片尺寸过大，请参考输入参数中关于图片大小限制的说明。
 FAILEDOPERATION_IMAGESIZETOOLARGE = 'FailedOperation.ImageSizeTooLarge'
 
+# 视读区信息与机读区信息不一致
+FAILEDOPERATION_INCONSISTENCYBETWEENMRZANDVRZ = 'FailedOperation.InconsistencyBetweenMRZAndVRZ'
+
+# 马来西亚证件识别出的邮编长度不正确
+FAILEDOPERATION_INVALIDPOSTALCODELENGTH = 'FailedOperation.InvalidPostalCodeLength'
+
 # 发票数据不一致。温馨提示：新版发票核验接口功能更完整，请尽快切换，如已切换请忽略。
 FAILEDOPERATION_INVOICEMISMATCH = 'FailedOperation.InvoiceMismatch'
 
 # 输入的Language不支持。
 FAILEDOPERATION_LANGUAGENOTSUPPORT = 'FailedOperation.LanguageNotSupport'
 
-# 照片中存在多张卡。
+# 入参CardSide错误，与实际上传的卡证正副页类型不符
+FAILEDOPERATION_LICENSECARDSIDEERROR = 'FailedOperation.LicenseCardSideError'
+
+# 图片中存在两张及以上同面卡证，请上传卡证单面图片或一正一反双面图片
+FAILEDOPERATION_LICENSEMULTICARDERROR = 'FailedOperation.LicenseMultiCardError'
+
+# 图片中存在两张及以上同面卡证，请上传卡证单面图片或一正一反双面图片。
 FAILEDOPERATION_MULTICARDERROR = 'FailedOperation.MultiCardError'
 
 # 非银行卡。
@@ -86,6 +101,9 @@ FAILEDOPERATION_NOBANKCARDERROR = 'FailedOperation.NoBankCardError'
 # 非营业执照。
 FAILEDOPERATION_NOBIZLICENSE = 'FailedOperation.NoBizLicense'
 
+# 上传的图片非驾驶证
+FAILEDOPERATION_NODRIVERLICENSEERROR = 'FailedOperation.NoDriverLicenseError'
+
 # 非香港身份证。
 FAILEDOPERATION_NOHKIDCARD = 'FailedOperation.NoHKIDCard'
 
@@ -95,20 +113,29 @@ FAILEDOPERATION_NOMASIDCARD = 'FailedOperation.NoMASIDCard'
 # 非护照。
 FAILEDOPERATION_NOPASSPORT = 'FailedOperation.NoPassport'
 
+# 图片不属于门头照
+FAILEDOPERATION_NOSTORELABEL = 'FailedOperation.NoStoreLabel'
+
+# 上传的图片非行驶证
+FAILEDOPERATION_NOVEHICLELICENSEERROR = 'FailedOperation.NoVehicleLicenseError'
+
 # OCR识别失败。
 FAILEDOPERATION_OCRFAILED = 'FailedOperation.OcrFailed'
 
-# 查询无记录。
-FAILEDOPERATION_QUERYNORECORD = 'FailedOperation.QueryNoRecord'
+# PDF解析失败。
+FAILEDOPERATION_PDFPARSEFAILED = 'FailedOperation.PDFParseFailed'
 
 # 未知错误。
 FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'
 
+# 未知的文件类型。
+FAILEDOPERATION_UNKNOWFILETYPEERROR = 'FailedOperation.UnKnowFileTypeError'
+
 # 服务未开通。
 FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'
 
-# 剩余识别次数不足，请检查资源包状态。
-FAILEDOPERATION_USERQUOTAERROR = 'FailedOperation.UserQuotaError'
+# 通用告警服务异常
+FAILEDOPERATION_WARNINGSERVICEFAILED = 'FailedOperation.WarningServiceFailed'
 
 # 内部错误。
 INTERNALERROR = 'InternalError'
@@ -119,9 +146,6 @@ INVALIDPARAMETER_CONFIGFORMATERROR = 'InvalidParameter.ConfigFormatError'
 # 图片解码失败。
 INVALIDPARAMETER_ENGINEIMAGEDECODEFAILED = 'InvalidParameter.EngineImageDecodeFailed'
 
-# 任务创建失败，文件URL非法。
-INVALIDPARAMETERVALUE_FILEURLILLEGALERROR = 'InvalidParameterValue.FileUrlIllegalError'
-
 # 参数值错误。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'
 
@@ -152,6 +176,12 @@ RESOURCENOTFOUND_NOINVOICE = 'ResourceNotFound.NoInvoice'
 # 不支持当天发票查询。
 RESOURCENOTFOUND_NOTSUPPORTCURRENTINVOICEQUERY = 'ResourceNotFound.NotSupportCurrentInvoiceQuery'
 
+# 账号已欠费。
+RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'
+
+# 账号资源包耗尽。
+RESOURCEUNAVAILABLE_RESOURCEPACKAGERUNOUT = 'ResourceUnavailable.ResourcePackageRunOut'
+
 # 税务局网络异常，请稍后访问。
 RESOURCEUNAVAILABLE_TAXNETWORKERROR = 'ResourceUnavailable.TaxNetworkError'
 
